
# Enum: classifier_callback_mode_enum


Callback modes while fitting a classifier.

URI: [https://w3id.org/neat/classifier_callback_mode_enum](https://w3id.org/neat/classifier_callback_mode_enum)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| auto | In 'auto' mode, the direction is automatically inferred from the name of the monitored quantity. |  |  |
| min | In 'min' mode, the learning rate will be reduced when the quantity monitored has stopped decreasing. |  |  |
| max | In 'max' mode, the learning rate will be reduced when the quantity monitored has stopped increasing |  |  |

